@@ -39,7 +39,7 @@ pthread_cond_t requests_cv;
 static int
 handle_request(int fd,
 	       char *buf,
-	       struct sockaddr_in *remote_addr)
+	       struct sockaddr_gen *remote_addr)
 {
     struct kernel *kp;
     int local_port, remote_port;
@@ -64,7 +64,7 @@ handle_request(int fd,
 	
 	kp = kernel_alloc();
 	kp->remote = *remote_addr;
-	kp->remote.sin_port = htons(remote_port);
+	SGPORT(kp->remote) = htons(remote_port);
 	
 	len = sizeof(kp->local);
 	if (s_getsockname(fd, (struct sockaddr *) &kp->local, &len) < 0)
@@ -74,7 +74,7 @@ handle_request(int fd,
 	    return -1;
 	}
 	
-	kp->local.sin_port = htons(local_port);
+	SGPORT(kp->local) = htons(local_port);
 	
 	kernel_query(kp);
 
