@@ -64,7 +64,7 @@ send_error(int fd,
 	   int l_port,
 	   int r_port,
 	   const char *what,
-	   struct sockaddr_in *remote_addr)
+	   struct sockaddr_gen *remote_addr)
 {
     char buf[1024];
     char buf2[32];
@@ -77,7 +77,7 @@ send_error(int fd,
     if (result_syslog_level > -1)
 	syslog(result_syslog_level,
 	       "reply to %s: %d , %d : ERROR: %s",
-	       s_inet_ntoa(remote_addr->sin_addr, buf2, sizeof(buf2)),
+	       s_inet_ntox(remote_addr, buf2, sizeof(buf2)),
 	       l_port, r_port, what);
 }
 
@@ -108,8 +108,8 @@ send_result(int fd,
 	syslog(LOG_INFO, "User %s elected to use .noident", pp->pw_name);
 	
 	send_error(fd,
-		   ntohs(kp->local.sin_port),
-		   ntohs(kp->remote.sin_port),
+		   ntohs(SGPORT(kp->local)),
+		   ntohs(SGPORT(kp->remote)),
 		   "HIDDEN-USER",
 		   &kp->remote);
 	return;
@@ -123,8 +123,8 @@ send_result(int fd,
 	pdes_encrypt(kp, buffer);
 	s_snprintf(buf, sizeof(buf),
 		 "%d , %d : USERID : OTHER%s%s :[%s]\r\n",
-		 ntohs(kp->local.sin_port),
-		 ntohs(kp->remote.sin_port),
+		 ntohs(SGPORT(kp->local)),
+		 ntohs(SGPORT(kp->remote)),
 		 charset != NULL ? " , " : "",
 		 charset != NULL ? charset : "",
 		 buffer);
@@ -136,8 +136,8 @@ send_result(int fd,
     {
 	s_snprintf(buf, sizeof(buf),
 		 "%d , %d : USERID : %s%s%s :%s\r\n",
-		 ntohs(kp->local.sin_port),
-		 ntohs(kp->remote.sin_port),
+		 ntohs(SGPORT(kp->local)),
+		 ntohs(SGPORT(kp->remote)),
 		 opsys,
 		 charset != NULL ? " , " : "",
 		 charset != NULL ? charset : "",
@@ -147,8 +147,8 @@ send_result(int fd,
     {
 	s_snprintf(buf, sizeof(buf),
 		 "%d , %d : USERID : OTHER :%ld\r\n",
-		 ntohs(kp->local.sin_port),
-		 ntohs(kp->remote.sin_port),
+		 ntohs(SGPORT(kp->local)),
+		 ntohs(SGPORT(kp->remote)),
 		 (long) uid);
     }
     
@@ -157,7 +157,7 @@ send_result(int fd,
     if (result_syslog_level > -1)
 	syslog(result_syslog_level,
 	       "reply to %s: %.*s",
-	       s_inet_ntoa(kp->remote.sin_addr, buf2, sizeof(buf2)),
+	       s_inet_ntox(&kp->remote, buf2, sizeof(buf2)),
 	       strlen(buf)-2, buf);
 }
 
@@ -165,7 +165,7 @@ send_result(int fd,
 
 void
 send_version(int fd,
-	     struct sockaddr_in *remote_addr)
+	     struct sockaddr_gen *remote_addr)
 {
     char buf[1024], buf2[32];
     
@@ -179,6 +179,6 @@ send_version(int fd,
     if (result_syslog_level > -1)
 	syslog(result_syslog_level,
 	       "reply to %s: %.*s",
-	       s_inet_ntoa(remote_addr->sin_addr, buf2, sizeof(buf2)),
+	       s_inet_ntox(remote_addr, buf2, sizeof(buf2)),
 	       strlen(buf)-2, buf);
 }
