@@ -98,12 +98,14 @@ server_init(void)
 		   listen_port);
 	    return -1;
 	}
+    }
 
-	if (listen(listen_sock, listen_backlog) < 0)
-	{
-	    syslog(LOG_ERR, "listen(backlog=%d) failed: %m", listen_backlog);
-	    return -1;
-	}
+    /* We do this outside of the 'if' statement to support
+       some broken 'inetd' daemons... */
+    if (listen(listen_sock, listen_backlog) < 0)
+    {
+	syslog(LOG_ERR, "listen(backlog=%d) failed: %m", listen_backlog);
+	return -1;
     }
 
     return 0;
